@@ -371,9 +371,8 @@ func (tree *Tree) databasesToNodes(children map[string][]string, node *tview.Tre
 			childNode := tview.NewTreeNode(child)
 			childNode.SetExpanded(defaultExpanded)
 			childNode.SetColor(app.Styles.PrimaryTextColor)
-			if tree.DBDriver.GetProvider() == "sqlite3" {
-				childNode.SetReference(child)
-			} else if tree.DBDriver.UseSchemas() {
+
+			if tree.DBDriver.UseSchemas() {
 				if supportsProgramming {
 					childNode.SetReference(fmt.Sprintf("%s.%s.tables.%s", nodeReference, key, child))
 				} else {
@@ -393,12 +392,12 @@ func (tree *Tree) databasesToNodes(children map[string][]string, node *tview.Tre
 }
 
 func (tree *Tree) addProgrammingNodes(functions map[string][]string, procedures map[string][]string, views map[string][]string, node *tview.TreeNode) {
-	var database = node.GetText()
-	var dbFunctions = functions[database]
+	database := node.GetText()
+	dbFunctions := functions[database]
 	sort.Strings(dbFunctions)
 
 	var functionsNode *tview.TreeNode
-	var functionsNodeReference = fmt.Sprintf("%s.functions", node.GetReference().(string))
+	functionsNodeReference := fmt.Sprintf("%s.functions", node.GetReference().(string))
 	functionsNode = tview.NewTreeNode("functions")
 	functionsNode.SetExpanded(false)
 	functionsNode.SetReference(functionsNodeReference)
@@ -413,11 +412,11 @@ func (tree *Tree) addProgrammingNodes(functions map[string][]string, procedures
 		functionsNode.AddChild(functionNode)
 	}
 
-	var dbProcedures = procedures[database]
+	dbProcedures := procedures[database]
 	sort.Strings(dbProcedures)
 
 	var proceduresNode *tview.TreeNode
-	var proceduresNodeReference = fmt.Sprintf("%s.procedures", node.GetReference().(string))
+	proceduresNodeReference := fmt.Sprintf("%s.procedures", node.GetReference().(string))
 	proceduresNode = tview.NewTreeNode("procedures")
 	proceduresNode.SetExpanded(false)
 	proceduresNode.SetReference(proceduresNodeReference)
@@ -432,11 +431,11 @@ func (tree *Tree) addProgrammingNodes(functions map[string][]string, procedures
 		proceduresNode.AddChild(procedureNode)
 	}
 
-	var dbViews = views[database]
+	dbViews := views[database]
 	sort.Strings(dbViews)
 
 	var viewsNode *tview.TreeNode
-	var viewsNodeReference = fmt.Sprintf("%s.views", node.GetReference().(string))
+	viewsNodeReference := fmt.Sprintf("%s.views", node.GetReference().(string))
 	viewsNode = tview.NewTreeNode("views")
 	viewsNode.SetExpanded(false)
 	viewsNode.SetReference(viewsNodeReference)
@@ -791,9 +790,14 @@ func (tree *Tree) InitializeNodes(dbName string) {
 		if err != nil {
 			panic(err.Error())
 		}
-		databases = dbs
+		sanitizedDbs := make([]string, 0, len(dbs))
+		for _, db := range dbs {
+			sanitizedDbs = append(sanitizedDbs, sanitizeDBName(db))
+		}
+		databases = sanitizedDbs
 	} else {
-		databases = []string{dbName}
+		sanitizedDBName := sanitizeDBName(dbName)
+		databases = []string{sanitizedDBName}
 	}
 
 	for _, database := range databases {
@@ -852,3 +856,8 @@ func (tree *Tree) ClearSearch() {
 	tree.SetBorderPadding(0, 0, 0, 0)
 	tree.Filter.SetText("")
 }
+
+func sanitizeDBName(dbName string) string {
+	// Remove dots from db name
+	return strings.ReplaceAll(dbName, ".", "_")
+}
